==> hyperpolyglot-0.1.0.crate: hyperpolyglot-0.1.0/src/codegen/interpreter-language-map.rs <==
static INTERPRETERS: phf::Map<&'static str, &[&str]> =
::phf::Map {
    key: 3213172566270843353,
    disps: ::phf::Slice::Static(&[
        (1, 33),
        (2, 117),
        (0, 68),
        (0, 3),
        (0, 19),
        (2, 13),
        (0, 90),
        (0, 0),
        (0, 1),
        (1, 100),
        (0, 19),
        (0, 112),
        (2, 94),
        (0, 102),
        (2, 113),
        (7, 98),
        (13, 45),
        (2, 7),
        (0, 96),
        (0, 2),
        (2, 122),
        (7, 81),
        (0, 1),
        (0, 8),
        (0, 28),
    ]),
    entries: ::phf::Slice::Static(&[
        ("mmi", &["Mercury"]),
        ("node", &["JavaScript"]),
        ("picolisp", &["PicoLisp"]),
        ("coffee", &["CoffeeScript"]),
        ("dtrace", &["DTrace"]),
        ("tcc", &["C"]),
        ("io", &["Io"]),
        ("yices2", &["SMT"]),
        ("awk", &["Awk"]),
        ("csh", &["Tcsh"]),
        ("instantfpc", &["Pascal"]),
        ("boolector", &["SMT"]),
        ("sed", &["sed"]),
        ("rakudo", &["Raku"]),
        ("pdksh", &["Shell"]),
        ("csi", &["Scheme"]),
        ("groovy", &["Groovy"]),
        ("verit", &["SMT"]),
        ("jolie", &["Jolie"]),
        ("qjs", &["JavaScript"]),
        ("qmake", &["QMake"]),
        ("perl", &["Perl", "Pod"]),
        ("python", &["Python"]),
        ("Rscript", &["R"]),
        ("ash", &["Shell"]),
        ("chicken", &["Scheme"]),
        ("dash", &["Shell"]),
        ("perl6", &["Pod 6", "Raku"]),
        ("ts-node", &["TypeScript"]),
        ("dyalog", &["APL"]),
        ("smtinterpol", &["SMT"]),
        ("yap", &["Prolog"]),
        ("regina", &["REXX"]),
        ("osascript", &["AppleScript"]),
        ("hy", &["Hy"]),
        ("pil", &["PicoLisp"]),
        ("rake", &["Ruby"]),
        ("scheme", &["Scheme"]),
        ("asy", &["Asymptote"]),
        ("dart", &["Dart"]),
        ("tclsh", &["Tcl"]),
        ("ruby", &["Ruby"]),
        ("sbcl", &["Common Lisp"]),
        ("jruby", &["Ruby"]),
        ("stp", &["SMT"]),
        ("runhaskell", &["Haskell"]),
        ("minised", &["sed"]),
        ("sclang", &["SuperCollider"]),
        ("sh", &["Shell"]),
        ("opensmt", &["SMT"]),
        ("ccl", &["Common Lisp"]),
        ("chakra", &["JavaScript"]),
        ("js", &["JavaScript"]),
        ("rhino", &["JavaScript"]),
        ("z3", &["SMT"]),
        ("mathsat5", &["SMT"]),
        ("crystal", &["Crystal"]),
        ("php", &["PHP"]),
        ("d8", &["JavaScript"]),
        ("raku", &["Raku"]),
        ("swipl", &["Prolog"]),
        ("clisp", &["Common Lisp"]),
        ("ksh", &["Shell"]),
        ("gjs", &["JavaScript"]),
        ("nush", &["Nu"]),
        ("cvc4", &["SMT"]),
        ("rexx", &["REXX"]),
        ("gosh", &["Scheme"]),
        ("v8", &["JavaScript"]),
        ("deno", &["TypeScript"]),
        ("gerbview", &["Gerber Image"]),
        ("tcsh", &["Tcsh"]),
        ("python2", &["Python"]),
        ("rune", &["E"]),
        ("jconsole", &["J"]),
        ("v8-shell", &["JavaScript"]),
        ("smt-rat", &["SMT"]),
        ("gnuplot", &["Gnuplot"]),
        ("zsh", &["Shell"]),
        ("cperl", &["Perl"]),
        ("ocamlrun", &["OCaml"]),
        ("bash", &["Shell"]),
        ("mawk", &["Awk"]),
        ("cwl-runner", &["Common Workflow Language"]),
        ("ssed", &["sed"]),
        ("escript", &["Erlang"]),
        ("moon", &["MoonScript"]),
        ("macruby", &["Ruby"]),
        ("rc", &["Shell"]),
        ("nextflow", &["Nextflow"]),
        ("wish", &["Tcl"]),
        ("mksh", &["Shell"]),
        ("ocamlscript", &["OCaml"]),
        ("fish", &["fish"]),
        ("apl", &["APL"]),
        ("gerbv", &["Gerber Image"]),
        ("ioke", &["Ioke"]),
        ("make", &["Makefile"]),
        ("scsynth", &["SuperCollider"]),
        ("nawk", &["Awk"]),
        ("gn", &["GN"]),
        ("pwsh", &["PowerShell"]),
        ("lsl", &["LSL"]),
        ("lua", &["Lua", "Terra"]),
        ("gawk", &["Awk"]),
        ("guile", &["Scheme"]),
        ("scala", &["Scala"]),
        ("python3", &["Python"]),
        ("openrc-run", &["OpenRC runscript"]),
        ("elixir", &["Elixir"]),
        ("aplx", &["APL"]),
        ("ocaml", &["OCaml", "Reason"]),
        ("lisp", &["Common Lisp"]),
        ("parrot", &["Parrot Assembly", "Parrot Internal Representation"]),
        ("pike", &["Pike"]),
        ("ecl", &["Common Lisp"]),
        ("makeinfo", &["Texinfo"]),
        ("gsed", &["sed"]),
        ("newlisp", &["NewLisp"]),
        ("rbx", &["Ruby"]),
        ("julia", &["Julia"]),
        ("r6rs", &["Scheme"]),
        ("racket", &["Racket"]),
        ("bigloo", &["Scheme"]),
    ]),
};

==> hyperpolyglot-0.1.3.crate: hyperpolyglot-0.1.3/src/codegen/interpreter-language-map.rs <==
static INTERPRETERS: phf::Map<&'static str, &[&str]> =
::phf::Map {
    key: 3213172566270843353,
    disps: ::phf::Slice::Static(&[
        (1, 33),
        (2, 117),
        (0, 68),
        (0, 3),
        (0, 19),
        (2, 13),
        (0, 90),
        (0, 0),
        (0, 1),
        (1, 100),
        (0, 19),
        (0, 112),
        (2, 94),
        (0, 102),
        (2, 113),
        (7, 98),
        (13, 45),
        (2, 7),
        (0, 96),
        (0, 2),
        (2, 122),
        (7, 81),
        (0, 1),
        (0, 8),
        (0, 28),
    ]),
    entries: ::phf::Slice::Static(&[
        ("mmi", &["Mercury"]),
        ("node", &["JavaScript"]),
        ("picolisp", &["PicoLisp"]),
        ("coffee", &["CoffeeScript"]),
        ("dtrace", &["DTrace"]),
        ("tcc", &["C"]),
        ("io", &["Io"]),
        ("yices2", &["SMT"]),
        ("awk", &["Awk"]),
        ("csh", &["Tcsh"]),
        ("instantfpc", &["Pascal"]),
        ("boolector", &["SMT"]),
        ("sed", &["sed"]),
        ("rakudo", &["Raku"]),
        ("pdksh", &["Shell"]),
        ("csi", &["Scheme"]),
        ("groovy", &["Groovy"]),
        ("verit", &["SMT"]),
        ("jolie", &["Jolie"]),
        ("qjs", &["JavaScript"]),
        ("qmake", &["QMake"]),
        ("perl", &["Pod", "Perl"]),
        ("python", &["Python"]),
        ("Rscript", &["R"]),
        ("ash", &["Shell"]),
        ("chicken", &["Scheme"]),
        ("dash", &["Shell"]),
        ("perl6", &["Raku", "Pod 6"]),
        ("ts-node", &["TypeScript"]),
        ("dyalog", &["APL"]),
        ("smtinterpol", &["SMT"]),
        ("yap", &["Prolog"]),
        ("regina", &["REXX"]),
        ("osascript", &["AppleScript"]),
        ("hy", &["Hy"]),
        ("pil", &["PicoLisp"]),
        ("rake", &["Ruby"]),
        ("scheme", &["Scheme"]),
        ("asy", &["Asymptote"]),
        ("dart", &["Dart"]),
        ("tclsh", &["Tcl"]),
        ("ruby", &["Ruby"]),
        ("sbcl", &["Common Lisp"]),
        ("jruby", &["Ruby"]),
        ("stp", &["SMT"]),
        ("runhaskell", &["Haskell"]),
        ("minised", &["sed"]),
        ("sclang", &["SuperCollider"]),
        ("sh", &["Shell"]),
        ("opensmt", &["SMT"]),
        ("ccl", &["Common Lisp"]),
        ("chakra", &["JavaScript"]),
        ("js", &["JavaScript"]),
        ("rhino", &["JavaScript"]),
        ("z3", &["SMT"]),
        ("mathsat5", &["SMT"]),
        ("crystal", &["Crystal"]),
        ("php", &["PHP"]),
        ("d8", &["JavaScript"]),
        ("raku", &["Raku"]),
        ("swipl", &["Prolog"]),
        ("clisp", &["Common Lisp"]),
        ("ksh", &["Shell"]),
        ("gjs", &["JavaScript"]),
        ("nush", &["Nu"]),
        ("cvc4", &["SMT"]),
        ("rexx", &["REXX"]),
        ("gosh", &["Scheme"]),
        ("v8", &["JavaScript"]),
        ("deno", &["TypeScript"]),
        ("gerbview", &["Gerber Image"]),
        ("tcsh", &["Tcsh"]),
        ("python2", &["Python"]),
        ("rune", &["E"]),
        ("jconsole", &["J"]),
        ("v8-shell", &["JavaScript"]),
        ("smt-rat", &["SMT"]),
        ("gnuplot", &["Gnuplot"]),
        ("zsh", &["Shell"]),
        ("cperl", &["Perl"]),
        ("ocamlrun", &["OCaml"]),
        ("bash", &["Shell"]),
        ("mawk", &["Awk"]),
        ("cwl-runner", &["Common Workflow Language"]),
        ("ssed", &["sed"]),
        ("escript", &["Erlang"]),
        ("moon", &["MoonScript"]),
        ("macruby", &["Ruby"]),
        ("rc", &["Shell"]),
        ("nextflow", &["Nextflow"]),
        ("wish", &["Tcl"]),
        ("mksh", &["Shell"]),
        ("ocamlscript", &["OCaml"]),
        ("fish", &["fish"]),
        ("apl", &["APL"]),
        ("gerbv", &["Gerber Image"]),
        ("ioke", &["Ioke"]),
        ("make", &["Makefile"]),
        ("scsynth", &["SuperCollider"]),
        ("nawk", &["Awk"]),
        ("gn", &["GN"]),
        ("pwsh", &["PowerShell"]),
        ("lsl", &["LSL"]),
        ("lua", &["Terra", "Lua"]),
        ("gawk", &["Awk"]),
        ("guile", &["Scheme"]),
        ("scala", &["Scala"]),
        ("python3", &["Python"]),
        ("openrc-run", &["OpenRC runscript"]),
        ("elixir", &["Elixir"]),
        ("aplx", &["APL"]),
        ("ocaml", &["OCaml", "Reason"]),
        ("lisp", &["Common Lisp"]),
        ("parrot", &["Parrot Internal Representation", "Parrot Assembly"]),
        ("pike", &["Pike"]),
        ("ecl", &["Common Lisp"]),
        ("makeinfo", &["Texinfo"]),
        ("gsed", &["sed"]),
        ("newlisp", &["NewLisp"]),
        ("rbx", &["Ruby"]),
        ("julia", &["Julia"]),
        ("r6rs", &["Scheme"]),
        ("racket", &["Racket"]),
        ("bigloo", &["Scheme"]),
    ]),
};
